/*
    Copyright (C) 2005-2008  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _NNTPGRAB_UTILS_H_
#define _NNTPGRAB_UTILS_H_

#include <glib.h>
#include "nntpgrab_types.h"

#if !GLIB_CHECK_VERSION(2,14,0)
#include <pcre.h>
#define NNTPGRAB_REGEX   pcre
#else
#define NNTPGRAB_REGEX   GRegex
#endif

#if GLIB_CHECK_VERSION(2,16,0)
#include <gio/gio.h>
#endif

typedef struct _nntpgrab_folder {
    char folder[2048];
    gboolean has_subfolders;
} NNTPGrabFolder;

typedef struct _nzb {
    GList *files;
} NZB;

typedef struct _nzb_file {
    char subject[256];
    char poster[256];
    time_t stamp;
    guint64 filesize;
    GList *groups;
    GList *segments;
} NZBFile;

typedef struct _nzbcreator_group {
    char newsgroup[512];
    int group_id;
} NZBCreatorGroup;

typedef enum _nzbcreator_search_only_in {
    NZBCREATOR_SEARCH_ONLY_IN_SUBJECTS,
    NZBCREATOR_SEARCH_ONLY_IN_FILENAMES,
    NZBCREATOR_SEARCH_ONLY_IN_POSTERS
} NZBCreatorSearchOnlyIn;

typedef struct _nzbcreator_search_opts {
    char query[64];
    char username[64];
    char password[64];
    NZBCreatorSearchOnlyIn search_only_in;
    int max_age;
    gint64 minimal_file_size;
    gint64 maximal_file_size;
    int percentage_complete;
    int group_to_search;
    NNTPFileType file_type;
} NZBCreatorSearchOpts;

typedef struct _nzbcreator_file {
    gint64 file_id;
    char subject[256];
    char poster[256];
    int num_parts_found;
    int num_parts_expected;
    NNTPFileType file_type;
    gint64 file_size;
    time_t stamp;
    int complete_percentage;
} NZBCreatorFile;

typedef struct _nzbcreator_collection {
    char collection_name[256];
    char newsgroup[256];
    gint64 total_file_size;
    time_t stamp;
    GList *files;                   // List of NZBCreatorFile* instances
} NZBCreatorCollection;

typedef struct _nzbcreator_search_result {
    int number_of_hits;
    int number_of_results;
    GList *collections;             // List of NZBCreatorCollection* instances
} NZBCreatorSearchResult;

NNTPGRAB_REGEX  *nntpgrab_utils_regex_compile(const char *regex);
void             nntpgrab_utils_regex_free(NNTPGRAB_REGEX *re);
const char     **nntpgrab_utils_regex_match(NNTPGRAB_REGEX *re, const char *line);
void             nntpgrab_utils_regex_matches_free(const char **matches);

gboolean         nntpgrab_utils_strip_subject(const char *subject, char **subject_without_partnum, char **suffix, int *file_num, int *total_files, char **filename, char **extension, NNTPFileType *file_type, int *par2_startnum, int *num_par2_blocks, int *part_num, int *total_parts);
char            *nntpgrab_utils_calculate_file_size(guint64 file_size);
int              nntpgrab_utils_calculate_estimated_time_remaining(int bytes_received1, int bytes_received2, int bytes_received3, int bytes_received4, int bytes_received5, int bytes_received6, int bytes_received7, int bytes_received8, int bytes_received9, int bytes_received10, guint64 file_size);
char            *nntpgrab_utils_get_readable_time_remaining(int estimated_time_remaining);
char            *nntpgrab_utils_get_readable_finished_time(int estimated_time_remaining);
void             nntpgrab_utils_sanitize_text(char *text, int length);
void             nntpgrab_utils_strip_nzb_extension(char *filename);

gboolean         nntpgrab_utils_get_folder_listing(const char *parent, GList **folders);
void             nntpgrab_utils_free_folder_listing(GList *folders);

NZB             *nntpgrab_utils_parse_nzb_file(const char *contents, char **errmsg);
void             nntpgrab_utils_nzb_file_free(NZB *nzbfile);

void                     nntpgrab_utils_nzbcreator_free_groups(GList *groups);
GList                   *nntpgrab_utils_nzbcreator_get_all_groups(char **errmsg);
void                     nntpgrab_utils_nzbcreator_free_result(NZBCreatorSearchResult *result);
NZBCreatorSearchResult  *nntpgrab_utils_nzbcreator_perform_search(NZBCreatorSearchOpts opts, char **errmsg);
char                    *nntpgrab_utils_nzbcreator_generate_NZB(GList *file_ids, char **errmsg);

#if GLIB_CHECK_VERSION(2,16,0)
GFileMonitor    *nntpgrab_utils_monitor_directory(const char *path, char **errmsg);
void             nntpgrab_utils_cancel_directory_monitor(GFileMonitor *monitor);
#endif

#endif /* _NNTPGRAB_UTILS_H_ */

