/*
    Copyright (C) 2005-2008  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "gui.h"

static void
fatal_error (NNTPGrabCore *core, const char *errmsg)
{
    g_error(_("Fatal error occured:\n%s\n"), errmsg);
}

static void
warning_message (NNTPGrabCore *core, const char *msg)
{
    GtkWidget *windowMain = nntpgrab_gui_base_get_widget("windowMain");
    nntpgrab_gui_base_dialog_show(windowMain, msg, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK);
}

#ifdef NNTPGRAB_NETWORKED
static void
connection_lost (NNTPGrabCore *core, const char *errmsg)
{
    g_critical(errmsg);
    gtk_main_quit();
}
#endif

void
callbacks_initialize()
{
    g_signal_connect(core, "fatal_error", G_CALLBACK(fatal_error), NULL);
    g_signal_connect(core, "warning_message", G_CALLBACK(warning_message), NULL);
#ifdef NNTPGRAB_NETWORKED
    g_signal_connect(core, "connection_lost", G_CALLBACK(connection_lost), NULL);
#endif
}

