/*
    Copyright (C) 2005-2008  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "nntpgrab.h"
#include "gui.h"

static GtkTextBuffer *buffer = NULL;
static gboolean is_visible = FALSE;

G_MODULE_EXPORT void
on_btnShowDebug_clicked(GtkWidget *caller, gpointer data)
{
    GtkWidget *windowDebug;

    windowDebug = nntpgrab_gui_base_get_widget("windowDebug");
    gtk_widget_show(windowDebug);
    is_visible = TRUE;
}

G_MODULE_EXPORT gboolean
on_windowDebug_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
    gtk_widget_hide(widget);
    is_visible = FALSE;

    if (buffer) {
        gtk_text_buffer_set_text(buffer, "", -1);
    }

    return TRUE;
}

static void
on_debug_message_cb(NNTPGrabCore *core, GThread *thread, const char *message, gpointer data)
{
    GtkTextIter iter;
    char *msg;

    if (!is_visible) {
        return;
    }

    if (!buffer) {
        GtkWidget *textview;
        textview = nntpgrab_gui_base_get_widget("textviewDebug");
        buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
    }

    msg = g_strdup_printf("Thread %#x: %s\n", GPOINTER_TO_INT(thread), message);
    gtk_text_buffer_get_end_iter(buffer, &iter);
    gtk_text_buffer_insert(buffer, &iter, msg, -1);
    g_free(msg);
}

void
debug_initialize(void)
{
    GtkWidget *windowDebug;

    windowDebug = nntpgrab_gui_base_get_widget("windowDebug");

    g_signal_connect(core, "debug_message", G_CALLBACK(on_debug_message_cb), windowDebug);
}

