/*
    Copyright (C) 2005-2008  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "nntpgrab_gui_base.h"
#include "icon_64x64.xpm"

#if GTK_CHECK_VERSION(2,10,0)

static GtkStatusIcon *tray_icon = NULL;
static gboolean trayIconActivated = FALSE;

GtkStatusIcon *
nntpgrab_gui_base_tray_get_status_icon(void)
{
    return tray_icon;
}

static void
tray_clicked(GtkWidget *caller, gpointer data)
{
    GtkWidget *windowMain = nntpgrab_gui_base_get_widget("windowMain");

    if (gtk_window_is_active(GTK_WINDOW(windowMain))) {
        gtk_window_iconify(GTK_WINDOW(windowMain));
        gtk_widget_hide(windowMain);
#ifndef WIN32
        gtk_window_set_skip_taskbar_hint(GTK_WINDOW(windowMain), TRUE);
#endif
    } else {
        gtk_widget_show(windowMain);
        gtk_window_present(GTK_WINDOW(windowMain));
#ifndef WIN32
        gtk_window_set_skip_taskbar_hint(GTK_WINDOW(windowMain), FALSE);
#endif
    }
}

static void
tray_popup (GtkStatusIcon *status_icon, guint button, guint activate_time, gpointer user_data)
{
    GtkWidget *menu;
    GtkWidget *item;

    menu = gtk_menu_new();

    item = gtk_menu_item_new_with_label(_("Show NNTPGrab"));
    g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(tray_clicked), NULL);
    gtk_widget_show(item);
    gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);

    item = gtk_menu_item_new_with_label(_("Close"));
    g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(gtk_main_quit), NULL);
    gtk_widget_show(item);
    gtk_menu_shell_append(GTK_MENU_SHELL(menu), item);

    gtk_widget_show(menu);
    gtk_menu_popup(GTK_MENU(menu), NULL, NULL, NULL, NULL, button, activate_time);
}

void
nntpgrab_gui_base_tray_destroy(void)
{
    g_return_if_fail(tray_icon != NULL);

    g_object_unref(tray_icon);

    tray_icon = NULL;

    trayIconActivated = FALSE;
}

void
nntpgrab_gui_base_tray_create(void)
{
    GdkPixbuf *pixbuf;

    if (tray_icon) {
        g_warning("tray_create(): tray_icon != NULL\n");
        nntpgrab_gui_base_tray_destroy();
    }

    trayIconActivated = FALSE;

    pixbuf = gdk_pixbuf_new_from_xpm_data((const char **) &icon_64x64_xpm);
    tray_icon = gtk_status_icon_new_from_pixbuf(pixbuf);
    g_object_unref(pixbuf);

    g_signal_connect(G_OBJECT(tray_icon), "activate", G_CALLBACK(tray_clicked), NULL);
    g_signal_connect(G_OBJECT(tray_icon), "popup-menu", G_CALLBACK(tray_popup), NULL);

    trayIconActivated = TRUE;
}

gboolean
nntpgrab_gui_base_tray_icon_get_is_shown(void)
{
    return trayIconActivated;
}

#else /* !GTK_CHECK_VERSION(2,10,0) */

void *
nntpgrab_gui_base_tray_get_status_icon(void)
{
    return NULL;
}

void
nntpgrab_gui_base_tray_destroy(void)
{
}

void
nntpgrab_gui_base_tray_create(void)
{
}

gboolean
nntpgrab_gui_base_tray_icon_get_is_shown(void)
{
    return FALSE;
}

#endif

