/*
    Copyright (C) 2005-2008  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _NNTPGRAB_H_
#define _NNTPGRAB_H_

#include <glib.h>

#include "nntpgrab_types.h"

G_BEGIN_DECLS

#define NNTPGRAB_API_VERSION    20081122

typedef struct NNTPGrabCore NNTPGrabCore;
typedef struct NNTPGrabCoreClass NNTPGrabCoreClass;

NNTPGrabCore   *nntpgrab_core_init(int version, char **err, char **warnings);
void            nntpgrab_core_cleanup(NNTPGrabCore *obj);

GList          *nntpgrab_config_get_avail_servers(NNTPGrabCore *obj);
void            nntpgrab_config_free_avail_servers(NNTPGrabCore *obj, GList *servers);
gboolean        nntpgrab_config_get_server_info(NNTPGrabCore *obj, const char *servername, ConfigServer *server);
gboolean        nntpgrab_config_add_server(NNTPGrabCore *obj, ConfigServer new_server);
gboolean        nntpgrab_config_del_server(NNTPGrabCore *obj, const char *servername);
gboolean        nntpgrab_config_edit_server(NNTPGrabCore *obj, const char *servername, ConfigServer server);
ConfigOpts      nntpgrab_config_get_opts(NNTPGrabCore *obj);
void            nntpgrab_config_set_opts(NNTPGrabCore *obj, ConfigOpts opts);
gboolean        nntpgrab_config_get_folder_listing(NNTPGrabCore *obj, const char *parent, GList **folders);
void            nntpgrab_config_free_folder_listing(NNTPGrabCore *obj, GList *folders);

gboolean        nntpgrab_schedular_start(NNTPGrabCore *obj);
gboolean        nntpgrab_schedular_stop(NNTPGrabCore *obj, gboolean wait);
SchedularState  nntpgrab_schedular_get_state(NNTPGrabCore *obj);
gboolean        nntpgrab_schedular_add_task_to_queue(NNTPGrabCore *obj, const char *collection_name, const char *subject, const char *poster, time_t stamp, guint64 file_size, GList *groups, GList *parts, char **errmsg);
gboolean        nntpgrab_schedular_del_task_from_queue(NNTPGrabCore *obj, const char *collection_name, const char *subject, char **errmsg);
gboolean        nntpgrab_schedular_restart_task(NNTPGrabCore *obj, const char *collection_name, const char *subject, char **errmsg);
gboolean        nntpgrab_schedular_save_queue(NNTPGrabCore *obj, char **errmsg);
void            nntpgrab_schedular_foreach_task(NNTPGrabCore *obj, ForeachCollectionFunc collection_func, ForeachFileFunc file_func, ForeachGroupFunc group_func, gpointer data);
gboolean        nntpgrab_schedular_move_task(NNTPGrabCore *obj, const char *collection_name_src, const char *subject_src, const char *collection_name_dest, int position_dest);
gboolean        nntpgrab_schedular_move_collection(NNTPGrabCore *obj, const char *collection_name, int new_position);

G_END_DECLS

#endif /* _NNTPGRAB_H_ */
