/*
    Copyright (C) 2005-2008  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _SCHEDULAR_H_
#define _SCHEDULAR_H_

#include "nntpgrab_types.h"
#include "collections.h"
#include "configuration.h"

typedef struct Schedular Schedular;

#define SCHEDULAR_TYPE_OBJECT       (schedular_get_type ())
#define SCHEDULAR(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), SCHEDULAR_TYPE_OBJECT, Schedular))
#define SCHEDULAR_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), SCHEDULAR_TYPE_OBJECT, SchedularClass))
#define IS_SCHEDULAR(object)        (G_TYPE_CHECK_INSTANCE_TYPE ((object), SCHEDULAR_TYPE_OBJECT))
#define IS_SCHEDULAR_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), SCHEDULAR_TYPE_OBJECT))
#define SCHEDULAR_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), SCHEDULAR_TYPE_OBJECT, SchedularClass))

Schedular       *schedular_new(Configuration *config, char **errmsg);
void             schedular_destroy(Schedular *obj);

gboolean         schedular_start(Schedular *obj);
gboolean         schedular_stop(Schedular *obj);
SchedularState   schedular_get_state(Schedular *obj);

gboolean         schedular_add_task_to_queue(Schedular *obj, const char *collection_name, const NNTPFile *file, char **errmsg);
gboolean         schedular_del_task_from_queue(Schedular *obj, const char *collection_name, const char *subject, char **errmsg);
gboolean         schedular_restart_task(Schedular *obj, const char *collection_name, const char *subject, char **errmsg);
gboolean         schedular_save_queue(Schedular *obj, char **errmsg);
void             schedular_foreach_task(Schedular *obj, ForeachCollectionFunc collection_func, ForeachFileFunc file_func, ForeachGroupFunc group_func, gpointer data);
gboolean         schedular_move_task(Schedular *obj, const char *collection_name_src, const char *subject_src, const char *collection_name_dest, int position_dest);
gboolean         schedular_move_collection(Schedular *obj, const char *collection_name, int new_position);

#endif /* _SCHEDULAR_H_ */
