/*
    Copyright (C) 2005-2008  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _NNTPGRAB_PLUGIN_PAR2_H_
#define _NNTPGRAB_PLUGIN_PAR2_H_

#include "nntpgrab_plugin_base.h"
#include "collections.h"

G_BEGIN_DECLS

// These are all the functions that the plugin can call to communicate with the NNTPGrab core
typedef struct _plugin_par2_imported_funcs {
    int version;

    void (*emit_repair_message) (const char *message);
} PluginPar2ImportedFuncs;

// The plugin needs to exported these methods :

/**
 * Initialize the plugin
 *
 * @arg     funcs   A structure containing all the callback functions the plugin can call to notify the NNTPGrab Core
 * @arg     errmsg  Pointer to a g_malloc'ed error message which will be set when the function returns FALSE
 *
 * @return          TRUE when the initialization was successfull
 */
gboolean     nntpgrab_plugin_par2_initialize(PluginPar2ImportedFuncs funcs, char **errmsg);

/**
 * Destroy the plugin
 */
void         nntpgrab_plugin_par2_destroy(void);

/**
 * Return the API version of the plugin. This is used to verify that the plugin is compatible
 * with the interface the NNTPGrab Core expects
 *
 * @return  NNTPGRAB_PLUGIN_API_VERSION
 */
int          nntpgrab_plugin_par2_get_version(void);

/**
 * Try to read any PAR2 verification data from the given file
 *
 * @arg     filename    The filename which should contain PAR2 verification data
 * @arg     par2set     A pointer in which the newly allocated par2set can be set
 *
 * @return               TRUE when PAR2 recovery data has been successfully read
 */
gboolean    nntpgrab_plugin_par2_load_verification_packet(const char *filename, PAR2Set **par2set);

/**
 * Repair the files using PAR2
 *
 * @arg     directory       The directory where all the files are situated
 * @arg     par2filename    The filename of (one of the) .par2 file(s)
 *
 * @return                  TRUE on success
 */
gboolean
nntpgrab_plugin_par2_repair_files(const char *directory, const char *par2filename);

G_END_DECLS

#endif /* _NNTPGRAB_PLUGIN_PAR2_H_ */

